bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 11. Aventiure
___________________________________________________
| ### <Do> di geste waren alle dan gevarn ### sprach ce sinem gesinde Sigemvndes barn ### wir svln vns ovch bereiten hæim in miniv lant ### liep was ez sinem wibe do ez div vrowe reht ervant ### Si sprach zv z ir manne wenne svl wir varn ### daz ich so harte gahe daz heiz ich wol bewarn ### mir svln ê mine brveder teilen mit div lant ### leit was ez Sifride do erz an Criemhild ervant
###### 689 | ### Di fvrsten zv zim giengen vnt sprachen alle dri ### nv wizet daz her Sifrit daz iv immer si ### mit triwen vnser dienest bereit reht vnz an den tot ### do neig er den dægenen do man imz so gvtlich erbot
| ### Wir svln ovch mit iv teilen sprach Giselher daz chint ### lant vnt bvrge di vnser eigen sint ### vnd swaz der witen riche ist vns vndertan ### der svlt ir teil vil gvten mit <samt> Criemhilde han
###### 691 | ### Svn der Sigemvndes zv den fvrsten sprach ### do er der herren willen gehorte vnd sach ### got laz iv iwer erbe immer sælich sin ### vnt ovch di lvete dar inne ia getvt div liebe wine min
###### 692 | ### des teiles wol ce rate den ir ir woldet ge [322a] ben ### da si sol tragen chrone vnt sol ich daz gelæben ### si mvz werden richer danne iemen lebendiger si ### <swaz> ir svs gebietet des pin ich iv dienestlichen bi
###### 693 | ### Do sprach div vrowe Criemhilt habt ir der erbe rat ### vmb Bvrgende dægene so liht ez niht enstat ### si mvg ein chvnich gerne fvren in sin lant ### ia sol si mit mir teilen miner <liben> brvoder hant
###### 694 | ### Do sprach der herre Gernot nv nim dir swen dv wil ### di gerne mit dir ritent der vindestv hi vil ### von drizech hvndert rechen wir geben dir tvsent man ### di sin <din> heimgesinde Criemhilt do senden began
| ### Nach Hagene von Tronege vnd ovch nach Ortwin ### ob di vnt ovch ir mage Criemhilde wolden sin ### do gewan dar vmbe Hagene ein zornlichez leben ### er sprach iane mach vns Gvnther ce werlde niemen gegeben
###### 696 | ### Ander iwer gesinde di lat iv volgen mite ### want ir doch wol bechennet der Tronegære site ### wir mveezen bi den chvnigen hiren hove bestan ### wir svln in langer dienen den wir al her gevolget han
###### 697 | ### Daz liezen si beliben do bereiten si sich dan ### ir edel ingesinde vrov Criemhilt zv zir gewan ### zw vnt drizech meide vnt fvmpfhvndert man ### Eckewart der grave der volgete Sifride dan
| ### Vrlovp si alle namen beidiv ritter vnt chneht ### mægede vnd vrowen daz was michel reht ### gescheiden chvssende wrden si cehant ### si rvmten vroelichen des kvnech Gvntheres lant
###### 699 | ### Do beleiten si ir mage vil verre vf den wegen ### man hiez in allenthalben ir nahtsælde lægen ### swa si se gerne namen al dvrch der chvnige lant ### do wrden botten balde Sigemvnde dan gesant
###### 700 | ### daz er daz wizen solde vnt ovch Sigelint ### daz sin svn chomen wolde vnd ovch vrovn Voten chint ### Criemhilt div vil schone von Wormez vber Rin ### done chvnden in div mære nimmer lieber gesin
| ### So wol mich sprach do Sigmvnt daz ich gelæbet han ### daz Criemhilt div vil schone sol hie gechronet gan ### des mvozen wol getiwert sin al div erbe min ### min svn der edel Sifrit sol hie selbe chvenech sin
###### 702 | ### Do gap div edele Sigelint vil manigen [322b] samit rot ### silber vnt golt vil swære daz was ir bottenbrot ### si vrevte sich der mære div si do vernam ### sich chleidete ir ingesinde mit vlize als in do wol gezam
###### 703 | ### Man sagete wer da chome mit im in daz lant ### do hiezen si gesidele rihten sa cehant ### dar zv er gecrhonet vor vrivnden solde gan ### do ritten im engegene des chvnich Sigemvndes man
| ### Ist iemen baz enpfangen daz ist mir vmbechant ### danne di helde mære in Sigemvndes lant ### Sigelint div schone Criemhilt engegene reit ### mit maniger vrowen schonen ir volgeten ritter gemeit
###### 705 | ### in einer tageweide da man di geste sach ### di chvnden vnt di vremden liden vngemach ### vnz daz si chomen ceiner bvrge wit ### div was gezeizen Santen da si chrone trvgen sit
###### 706 | ### Mit lachendem mvnde Sigelint vnt Sigmvnt ### chvsten Criemhilt dvrch liebe ce maniger stvnt ### vnt ovch Sifrit in was ir leit benomen ### allez ir gesinde was in groze willechomen
| ### Man bat di geste <bringen> fvr Sigmvndes sal ### di schonen ivnchvrowen di hvp man da ce tal ### nider von den moeren da was vil manich man ### do man den schonen vrowen mit <vlize> dienen began
###### 708 | ### Swi groz ir hohzit bi dem Rine was bechant ### noch gap man den helden hie vil bezer gewant ### denne si getrvgen noch bi allen ir tagen ### man mohte michel wnder von ir richeite sagen
###### 709 | ### Do si in ir hohen eren sazen vnd heten genvch ### waz golt varwer geren ir ingesinde trvch ### perln vnd edel gesteine verwieret wol dar in ### svs pflach ir vlizechlichen Sigelint div edel chvenegin
| ### Do sprach vor sinen vrivnden der herre Sigemvnt ### den Sifrides magen tvn ich allen chvnt ### er sol vor disen recken di mine chrone tragen ### div mære horten gerne di von Niderlande sagen
###### 711 | ### Er bevalch im sin gerihte crone vnd ovch daz lant ### sit was er ir aller meister di er ce rehte vant ### vnt dar er riten solde daz wart also getan ### daz man sere vorhte der shonen Crimhilden man
###### 712 | ### In disen grozen eren lebet er daz ist war ### vnd rihte vnder chrone vnz an daz cehende iar ### daz div vil schone vrowe einen svn gewan ### daz was des chvneges magen nach ir willen ergan [323a]
| ### Den ilte man do tovffen vnd gap im einen namen ### Gvnther nach sinem oheim des en dorft er sich niht schamen ### geriet er nach den magen daz wær im wol ergan ### do zoh man in mit vlize daz was von shvlden getan
###### 714 | ### In den selben ziten starp vrov Sigelint ### do het den gewalt mit alle der edeln Vote chint ### der so richen vrowen ob landen wol gezam ### daz chlagten do genvge <do> si der tot von in genam
###### 715 | ### Nv het ovch dort bi Rine so wir horen sagen ### bi Gvnther dem richen eienen svn getragen ### Prvnnhilt div schoene in Bvergvnden lant ### dvrch des heldes liebe wart er Sifrit genant
| ### Wi rehte vlizechlichen sin man hveten hiez ### Gvnther der edele im magezogen liez ### di ez wol chvnden ziehen ce einem biderbem man ### hey waz im vngelveche sit der vrivnde an gewan
###### 717 | ### Mære zallen ziten der wart vil geseit ### wi rehte lobelichen di recken vil gemeit ### lebten zallen stvnden in Sigemvndes lant ### alsam tet ovch Gvnther mit sinen magen vzer chant
###### 718 | ### Daz lant cen Nibelvngen Sifride diente hie ### richer siner mage wart noch deheiner nie ### vnt ovch Nibelvnges recken vnt ir beder gvt ### des trvch der vil chvene deste hoehern mvt
| ### Hort den aller meisten den helt ie gewan ### ane di es ê pflagen hæte nv der chvene man ### den e vor einem berge mit siner hende erstreit ### dar vmbe slvch er ce tode vil manigen ritter gemeit
###### 720 | ### Er heten wnsh der eren vnt wære des niht geshehen ### so mvese man <von> schvlden dem edeln rechen iehen ### daz <er> wære ein der beste der vf oerss ie gasaz ### man vorhte sine sterche vnt tet vil pilliche daz

<<< Übersicht <<< vorige Seite nächste Seite >>>